@@ -114,6 +114,18 @@ class usrp1_sink_base(_object):
         """daughterboard_id(self, int which_dboard) -> int"""
         return _usrp1.usrp1_sink_base_daughterboard_id(*args)
 
+    def set_adc_offset(*args): 
+        """set_adc_offset(self, int which, int offset) -> bool"""
+        return _usrp1.usrp1_sink_base_set_adc_offset(*args)
+
+    def set_dac_offset(*args): 
+        """set_dac_offset(self, int which, int offset, int offset_pin) -> bool"""
+        return _usrp1.usrp1_sink_base_set_dac_offset(*args)
+
+    def set_adc_buffer_bypass(*args): 
+        """set_adc_buffer_bypass(self, int which, bool bypass) -> bool"""
+        return _usrp1.usrp1_sink_base_set_adc_buffer_bypass(*args)
+
     def _write_oe(*args): 
         """_write_oe(self, int which_dboard, int value, int mask) -> bool"""
         return _usrp1.usrp1_sink_base__write_oe(*args)
@@ -127,11 +139,11 @@ class usrp1_sink_base(_object):
         return _usrp1.usrp1_sink_base_read_io(*args)
 
     def write_aux_dac(*args): 
-        """write_aux_dac(self, int slot, int which_dac, int value) -> bool"""
+        """write_aux_dac(self, int which_dboard, int which_dac, int value) -> bool"""
         return _usrp1.usrp1_sink_base_write_aux_dac(*args)
 
     def read_aux_adc(*args): 
-        """read_aux_adc(self, int slot, int which_adc) -> int"""
+        """read_aux_adc(self, int which_dboard, int which_adc) -> int"""
         return _usrp1.usrp1_sink_base_read_aux_adc(*args)
 
     def write_eeprom(*args): 
@@ -142,6 +154,14 @@ class usrp1_sink_base(_object):
         """read_eeprom(self, int i2c_addr, int eeprom_offset, int len) -> string"""
         return _usrp1.usrp1_sink_base_read_eeprom(*args)
 
+    def write_i2c(*args): 
+        """write_i2c(self, int i2c_addr, string buf) -> bool"""
+        return _usrp1.usrp1_sink_base_write_i2c(*args)
+
+    def read_i2c(*args): 
+        """read_i2c(self, int i2c_addr, int len) -> string"""
+        return _usrp1.usrp1_sink_base_read_i2c(*args)
+
     def _write_fpga_reg(*args): 
         """_write_fpga_reg(self, int regno, int value) -> bool"""
         return _usrp1.usrp1_sink_base__write_fpga_reg(*args)
@@ -245,6 +265,18 @@ class usrp1_source_base(_object):
         """daughterboard_id(self, int which_dboard) -> int"""
         return _usrp1.usrp1_source_base_daughterboard_id(*args)
 
+    def set_adc_offset(*args): 
+        """set_adc_offset(self, int which, int offset) -> bool"""
+        return _usrp1.usrp1_source_base_set_adc_offset(*args)
+
+    def set_dac_offset(*args): 
+        """set_dac_offset(self, int which, int offset, int offset_pin) -> bool"""
+        return _usrp1.usrp1_source_base_set_dac_offset(*args)
+
+    def set_adc_buffer_bypass(*args): 
+        """set_adc_buffer_bypass(self, int which, bool bypass) -> bool"""
+        return _usrp1.usrp1_source_base_set_adc_buffer_bypass(*args)
+
     def _write_oe(*args): 
         """_write_oe(self, int which_dboard, int value, int mask) -> bool"""
         return _usrp1.usrp1_source_base__write_oe(*args)
@@ -258,11 +290,11 @@ class usrp1_source_base(_object):
         return _usrp1.usrp1_source_base_read_io(*args)
 
     def write_aux_dac(*args): 
-        """write_aux_dac(self, int slot, int which_dac, int value) -> bool"""
+        """write_aux_dac(self, int which_dboard, int which_dac, int value) -> bool"""
         return _usrp1.usrp1_source_base_write_aux_dac(*args)
 
     def read_aux_adc(*args): 
-        """read_aux_adc(self, int slot, int which_adc) -> int"""
+        """read_aux_adc(self, int which_dboard, int which_adc) -> int"""
         return _usrp1.usrp1_source_base_read_aux_adc(*args)
 
     def write_eeprom(*args): 
@@ -273,6 +305,14 @@ class usrp1_source_base(_object):
         """read_eeprom(self, int i2c_addr, int eeprom_offset, int len) -> string"""
         return _usrp1.usrp1_source_base_read_eeprom(*args)
 
+    def write_i2c(*args): 
+        """write_i2c(self, int i2c_addr, string buf) -> bool"""
+        return _usrp1.usrp1_source_base_write_i2c(*args)
+
+    def read_i2c(*args): 
+        """read_i2c(self, int i2c_addr, int len) -> string"""
+        return _usrp1.usrp1_source_base_read_i2c(*args)
+
     def _write_fpga_reg(*args): 
         """_write_fpga_reg(self, int regno, int value) -> bool"""
         return _usrp1.usrp1_source_base__write_fpga_reg(*args)
@@ -376,6 +416,18 @@ class usrp1_sink_c_sptr(_object):
         """daughterboard_id(self, int which_dboard) -> int"""
         return _usrp1.usrp1_sink_c_sptr_daughterboard_id(*args)
 
+    def set_adc_offset(*args): 
+        """set_adc_offset(self, int which, int offset) -> bool"""
+        return _usrp1.usrp1_sink_c_sptr_set_adc_offset(*args)
+
+    def set_dac_offset(*args): 
+        """set_dac_offset(self, int which, int offset, int offset_pin) -> bool"""
+        return _usrp1.usrp1_sink_c_sptr_set_dac_offset(*args)
+
+    def set_adc_buffer_bypass(*args): 
+        """set_adc_buffer_bypass(self, int which, bool bypass) -> bool"""
+        return _usrp1.usrp1_sink_c_sptr_set_adc_buffer_bypass(*args)
+
     def _write_oe(*args): 
         """_write_oe(self, int which_dboard, int value, int mask) -> bool"""
         return _usrp1.usrp1_sink_c_sptr__write_oe(*args)
@@ -389,11 +441,11 @@ class usrp1_sink_c_sptr(_object):
         return _usrp1.usrp1_sink_c_sptr_read_io(*args)
 
     def write_aux_dac(*args): 
-        """write_aux_dac(self, int slot, int which_dac, int value) -> bool"""
+        """write_aux_dac(self, int which_dboard, int which_dac, int value) -> bool"""
         return _usrp1.usrp1_sink_c_sptr_write_aux_dac(*args)
 
     def read_aux_adc(*args): 
-        """read_aux_adc(self, int slot, int which_adc) -> int"""
+        """read_aux_adc(self, int which_dboard, int which_adc) -> int"""
         return _usrp1.usrp1_sink_c_sptr_read_aux_adc(*args)
 
     def write_eeprom(*args): 
@@ -404,6 +456,14 @@ class usrp1_sink_c_sptr(_object):
         """read_eeprom(self, int i2c_addr, int eeprom_offset, int len) -> string"""
         return _usrp1.usrp1_sink_c_sptr_read_eeprom(*args)
 
+    def write_i2c(*args): 
+        """write_i2c(self, int i2c_addr, string buf) -> bool"""
+        return _usrp1.usrp1_sink_c_sptr_write_i2c(*args)
+
+    def read_i2c(*args): 
+        """read_i2c(self, int i2c_addr, int len) -> string"""
+        return _usrp1.usrp1_sink_c_sptr_read_i2c(*args)
+
     def _write_fpga_reg(*args): 
         """_write_fpga_reg(self, int regno, int value) -> bool"""
         return _usrp1.usrp1_sink_c_sptr__write_fpga_reg(*args)
@@ -556,6 +616,18 @@ class usrp1_sink_s_sptr(_object):
         """daughterboard_id(self, int which_dboard) -> int"""
         return _usrp1.usrp1_sink_s_sptr_daughterboard_id(*args)
 
+    def set_adc_offset(*args): 
+        """set_adc_offset(self, int which, int offset) -> bool"""
+        return _usrp1.usrp1_sink_s_sptr_set_adc_offset(*args)
+
+    def set_dac_offset(*args): 
+        """set_dac_offset(self, int which, int offset, int offset_pin) -> bool"""
+        return _usrp1.usrp1_sink_s_sptr_set_dac_offset(*args)
+
+    def set_adc_buffer_bypass(*args): 
+        """set_adc_buffer_bypass(self, int which, bool bypass) -> bool"""
+        return _usrp1.usrp1_sink_s_sptr_set_adc_buffer_bypass(*args)
+
     def _write_oe(*args): 
         """_write_oe(self, int which_dboard, int value, int mask) -> bool"""
         return _usrp1.usrp1_sink_s_sptr__write_oe(*args)
@@ -569,11 +641,11 @@ class usrp1_sink_s_sptr(_object):
         return _usrp1.usrp1_sink_s_sptr_read_io(*args)
 
     def write_aux_dac(*args): 
-        """write_aux_dac(self, int slot, int which_dac, int value) -> bool"""
+        """write_aux_dac(self, int which_dboard, int which_dac, int value) -> bool"""
         return _usrp1.usrp1_sink_s_sptr_write_aux_dac(*args)
 
     def read_aux_adc(*args): 
-        """read_aux_adc(self, int slot, int which_adc) -> int"""
+        """read_aux_adc(self, int which_dboard, int which_adc) -> int"""
         return _usrp1.usrp1_sink_s_sptr_read_aux_adc(*args)
 
     def write_eeprom(*args): 
@@ -584,6 +656,14 @@ class usrp1_sink_s_sptr(_object):
         """read_eeprom(self, int i2c_addr, int eeprom_offset, int len) -> string"""
         return _usrp1.usrp1_sink_s_sptr_read_eeprom(*args)
 
+    def write_i2c(*args): 
+        """write_i2c(self, int i2c_addr, string buf) -> bool"""
+        return _usrp1.usrp1_sink_s_sptr_write_i2c(*args)
+
+    def read_i2c(*args): 
+        """read_i2c(self, int i2c_addr, int len) -> string"""
+        return _usrp1.usrp1_sink_s_sptr_read_i2c(*args)
+
     def _write_fpga_reg(*args): 
         """_write_fpga_reg(self, int regno, int value) -> bool"""
         return _usrp1.usrp1_sink_s_sptr__write_fpga_reg(*args)
@@ -749,6 +829,18 @@ class usrp1_source_c_sptr(_object):
         """daughterboard_id(self, int which_dboard) -> int"""
         return _usrp1.usrp1_source_c_sptr_daughterboard_id(*args)
 
+    def set_adc_offset(*args): 
+        """set_adc_offset(self, int which, int offset) -> bool"""
+        return _usrp1.usrp1_source_c_sptr_set_adc_offset(*args)
+
+    def set_dac_offset(*args): 
+        """set_dac_offset(self, int which, int offset, int offset_pin) -> bool"""
+        return _usrp1.usrp1_source_c_sptr_set_dac_offset(*args)
+
+    def set_adc_buffer_bypass(*args): 
+        """set_adc_buffer_bypass(self, int which, bool bypass) -> bool"""
+        return _usrp1.usrp1_source_c_sptr_set_adc_buffer_bypass(*args)
+
     def _write_oe(*args): 
         """_write_oe(self, int which_dboard, int value, int mask) -> bool"""
         return _usrp1.usrp1_source_c_sptr__write_oe(*args)
@@ -762,11 +854,11 @@ class usrp1_source_c_sptr(_object):
         return _usrp1.usrp1_source_c_sptr_read_io(*args)
 
     def write_aux_dac(*args): 
-        """write_aux_dac(self, int slot, int which_dac, int value) -> bool"""
+        """write_aux_dac(self, int which_dboard, int which_dac, int value) -> bool"""
         return _usrp1.usrp1_source_c_sptr_write_aux_dac(*args)
 
     def read_aux_adc(*args): 
-        """read_aux_adc(self, int slot, int which_adc) -> int"""
+        """read_aux_adc(self, int which_dboard, int which_adc) -> int"""
         return _usrp1.usrp1_source_c_sptr_read_aux_adc(*args)
 
     def write_eeprom(*args): 
@@ -777,6 +869,14 @@ class usrp1_source_c_sptr(_object):
         """read_eeprom(self, int i2c_addr, int eeprom_offset, int len) -> string"""
         return _usrp1.usrp1_source_c_sptr_read_eeprom(*args)
 
+    def write_i2c(*args): 
+        """write_i2c(self, int i2c_addr, string buf) -> bool"""
+        return _usrp1.usrp1_source_c_sptr_write_i2c(*args)
+
+    def read_i2c(*args): 
+        """read_i2c(self, int i2c_addr, int len) -> string"""
+        return _usrp1.usrp1_source_c_sptr_read_i2c(*args)
+
     def _write_fpga_reg(*args): 
         """_write_fpga_reg(self, int regno, int value) -> bool"""
         return _usrp1.usrp1_source_c_sptr__write_fpga_reg(*args)
@@ -942,6 +1042,18 @@ class usrp1_source_s_sptr(_object):
         """daughterboard_id(self, int which_dboard) -> int"""
         return _usrp1.usrp1_source_s_sptr_daughterboard_id(*args)
 
+    def set_adc_offset(*args): 
+        """set_adc_offset(self, int which, int offset) -> bool"""
+        return _usrp1.usrp1_source_s_sptr_set_adc_offset(*args)
+
+    def set_dac_offset(*args): 
+        """set_dac_offset(self, int which, int offset, int offset_pin) -> bool"""
+        return _usrp1.usrp1_source_s_sptr_set_dac_offset(*args)
+
+    def set_adc_buffer_bypass(*args): 
+        """set_adc_buffer_bypass(self, int which, bool bypass) -> bool"""
+        return _usrp1.usrp1_source_s_sptr_set_adc_buffer_bypass(*args)
+
     def _write_oe(*args): 
         """_write_oe(self, int which_dboard, int value, int mask) -> bool"""
         return _usrp1.usrp1_source_s_sptr__write_oe(*args)
@@ -955,11 +1067,11 @@ class usrp1_source_s_sptr(_object):
         return _usrp1.usrp1_source_s_sptr_read_io(*args)
 
     def write_aux_dac(*args): 
-        """write_aux_dac(self, int slot, int which_dac, int value) -> bool"""
+        """write_aux_dac(self, int which_dboard, int which_dac, int value) -> bool"""
         return _usrp1.usrp1_source_s_sptr_write_aux_dac(*args)
 
     def read_aux_adc(*args): 
-        """read_aux_adc(self, int slot, int which_adc) -> int"""
+        """read_aux_adc(self, int which_dboard, int which_adc) -> int"""
         return _usrp1.usrp1_source_s_sptr_read_aux_adc(*args)
 
     def write_eeprom(*args): 
@@ -970,6 +1082,14 @@ class usrp1_source_s_sptr(_object):
         """read_eeprom(self, int i2c_addr, int eeprom_offset, int len) -> string"""
         return _usrp1.usrp1_source_s_sptr_read_eeprom(*args)
 
+    def write_i2c(*args): 
+        """write_i2c(self, int i2c_addr, string buf) -> bool"""
+        return _usrp1.usrp1_source_s_sptr_write_i2c(*args)
+
+    def read_i2c(*args): 
+        """read_i2c(self, int i2c_addr, int len) -> string"""
+        return _usrp1.usrp1_source_s_sptr_read_i2c(*args)
+
     def _write_fpga_reg(*args): 
         """_write_fpga_reg(self, int regno, int value) -> bool"""
         return _usrp1.usrp1_source_s_sptr__write_fpga_reg(*args)
