@@ -157,23 +157,23 @@ class usrp1_sink_base : public gr_sync_block {
   /*!
    * \brief Write auxiliary digital to analog converter.
    *
-   * \param slot	Which Tx or Rx slot to write.
-   *    		N.B., SLOT_TX_A and SLOT_RX_A share the same AUX DAC's.
-   *          		SLOT_TX_B and SLOT_RX_B share the same AUX DAC's.
-   * \param which_dac	[0,3] RX slots must use only 0 and 1.  TX slots must use only 2 and 3.
-   * \param value	[0,4095]
+   * \param which_dboard	[0,1] which d'board
+   *    			N.B., SLOT_TX_A and SLOT_RX_A share the same AUX DAC's.
+   *          			SLOT_TX_B and SLOT_RX_B share the same AUX DAC's.
+   * \param which_dac		[2,3] TX slots must use only 2 and 3.
+   * \param value		[0,4095]
    * \returns true iff successful
    */
-  bool write_aux_dac (int slot, int which_dac, int value);
+  bool write_aux_dac (int which_board, int which_dac, int value);
 
   /*!
    * \brief Read auxiliary analog to digital converter.
    *
-   * \param slot	2-bit slot number. E.g., SLOT_TX_A
-   * \param which_adc	[0,1]
+   * \param which_dboard	[0,1] which d'board
+   * \param which_adc		[0,1]
    * \returns value in the range [0,4095] if successful, else READ_FAILED.
    */
-  int read_aux_adc (int slot, int which_adc);
+  int read_aux_adc (int which_dboard, int which_adc);
 
   /*!
    * \brief Write EEPROM on motherboard or any daughterboard.
@@ -193,6 +193,48 @@ class usrp1_sink_base : public gr_sync_block {
    */
   std::string read_eeprom (int i2c_addr, int eeprom_offset, int len);
 
+  /*!
+   * \brief Write to I2C peripheral
+   * \param i2c_addr		I2C bus address (7-bits)
+   * \param buf			the data to write
+   * \returns true iff successful
+   * Writes are limited to a maximum of of 64 bytes.
+   */
+  bool write_i2c (int i2c_addr, const std::string buf);
+
+  /*!
+   * \brief Read from I2C peripheral
+   * \param i2c_addr		I2C bus address (7-bits)
+   * \param len			number of bytes to read
+   * \returns the data read if successful, else a zero length string.
+   * Reads are limited to a maximum of of 64 bytes.
+   */
+  std::string read_i2c (int i2c_addr, int len);
+
+  /*!
+   * \brief Set ADC offset correction
+   * \param which	which ADC[0,3]: 0 = RX_A I, 1 = RX_A Q...
+   * \param offset	16-bit value to subtract from raw ADC input.
+   */
+  bool set_adc_offset (int which, int offset);
+
+  /*!
+   * \brief Set DAC offset correction
+   * \param which	which DAC[0,3]: 0 = TX_A I, 1 = TX_A Q...
+   * \param offset	10-bit offset value (ambiguous format:  See AD9862 datasheet).
+   * \param offset_pin	1-bit value.  If 0 offset applied to -ve differential pin;
+   *                                  If 1 offset applied to +ve differential pin.
+   */
+  bool set_dac_offset (int which, int offset, int offset_pin);
+
+  /*!
+   * \brief Control ADC input buffer
+   * \param which 	which ADC[0,3]
+   * \param bypass	if non-zero, bypass input buffer and connect input
+   *	                directly to switched cap SHA input of RxPGA.
+   */
+  bool set_adc_buffer_bypass (int which, bool bypass);
+
   /*!
    * \brief Write direction register (output enables) for pins that go to daughterboard.
    *
