@@ -176,15 +176,15 @@ usrp1_source_base::set_verbose (bool verbose)
 }
 
 bool
-usrp1_source_base::write_aux_dac (int slot, int which_dac, int value)
+usrp1_source_base::write_aux_dac (int which_dboard, int which_dac, int value)
 {
-  return d_usrp->write_aux_dac (slot, which_dac, value);
+  return d_usrp->write_aux_dac (which_dboard, which_dac, value);
 }
 
 int
-usrp1_source_base::read_aux_adc (int slot, int which_adc)
+usrp1_source_base::read_aux_adc (int which_dboard, int which_adc)
 {
-  return d_usrp->read_aux_adc (slot, which_adc);
+  return d_usrp->read_aux_adc (which_dboard, which_adc);
 }
 
 bool
@@ -199,6 +199,18 @@ usrp1_source_base::read_eeprom (int i2c_addr, int eeprom_offset, int len)
   return d_usrp->read_eeprom (i2c_addr, eeprom_offset, len);
 }
 
+bool
+usrp1_source_base::write_i2c (int i2c_addr, const std::string buf)
+{
+  return d_usrp->write_i2c (i2c_addr, buf);
+}
+
+std::string
+usrp1_source_base::read_i2c (int i2c_addr, int len)
+{
+  return d_usrp->read_i2c (i2c_addr, len);
+}
+
 bool
 usrp1_source_base::set_pga (int which, double gain)
 {
@@ -235,22 +247,41 @@ usrp1_source_base::daughterboard_id (int which) const
   return d_usrp->daughterboard_id (which);
 }
 
+
+bool
+usrp1_source_base::set_adc_offset (int which, int offset)
+{
+  return d_usrp->set_adc_offset (which, offset);
+}
+
+bool
+usrp1_source_base::set_dac_offset (int which, int offset, int offset_pin)
+{
+  return d_usrp->set_dac_offset (which, offset, offset_pin);
+}
+
+bool
+usrp1_source_base::set_adc_buffer_bypass (int which, bool bypass)
+{
+  return d_usrp->set_adc_buffer_bypass (which, bypass);
+}
+
 bool
 usrp1_source_base::_write_oe (int which_dboard, int value, int mask)
 {
-  return _write_oe (which_dboard, value, mask);
+  return d_usrp->_write_oe (which_dboard, value, mask);
 }
 
 bool
 usrp1_source_base::write_io (int which_dboard, int value, int mask)
 {
-  return write_io (which_dboard, value, mask);
+  return d_usrp->write_io (which_dboard, value, mask);
 }
 
 int
 usrp1_source_base::read_io (int which_dboard)
 {
-  return read_io (which_dboard);
+  return d_usrp->read_io (which_dboard);
 }
 
 // internal routines...
